@@ -31,7 +31,7 @@ CMDLINE_ARGS=("$@")
        GUI_TERM="urxvt"
       TERM_OPTS="-e"
  TERM_TITLE_OPT="--title"
-     GUI_FILERS="rox thunar spacefm"
+     GUI_FILERS="rox thunar spacefm zzz"
 
         ARCHIVE="archive"
 
@@ -942,8 +942,8 @@ clean_up() {
     delete_files_rf $TEMP_DIR
 
     local luks
-    for luks in LUKS_CLOSE; do
-        cryptsetup luksClose $luks
+    for luks in ${LUKS_CLOSE}; do
+        /usr/sbin/cryptsetup luksClose $luks
     done
 
     # Save log file to /root/Live-usb-storage/live-logs/ if available
